# coding: utf-8

# flake8: noqa
"""
    YooniK.Bit API

    Functionalities to control biometric capture or verification of the YooniK.BiT.  # noqa: E501

    OpenAPI spec version: 1.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from yk_bit.models.capture_request import CaptureRequest
from yk_bit.models.capture_response import CaptureResponse
from yk_bit.models.verify_request import VerifyRequest
from yk_bit.models.verify_response import VerifyResponse
from yk_bit.models.verify_images_request import VerifyImagesRequest
from yk_bit.models.verify_images_response import VerifyImagesResponse
